You can add arbitrary metadata to your instance so that you can more easily identify it among other running instances. Metadata is a collection of key-value pairs associated with an instance. The maximum length for each metadata key and value is 255 characters.

The maximum number of key-value pairs that can be supplied per instance is determined by the compute provider. This limit is currently set to {$ model.novaLimits.maxServerMeta $}. This limit is currently not set.